@@ -1,6 +1,7 @@
 #define __NO_VERSION__
+#include "adriver.h"
 #include <linux/version.h>
-#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 19)
+#ifndef CONFIG_HAVE_INIT_UTSNAME
 #define init_utsname()	(&system_utsname)
 #endif
 #include "../alsa-kernel/core/info_oss.c"
