@@ -16,7 +16,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-HPI Extended Message Handler Functions
+ HPI Extended Message Handler Functions
 
 (C) Copyright AudioScience Inc. 1997-2003
 ******************************************************************************/
@@ -27,26 +27,25 @@ HPI Extended Message Handler Functions
 #include "hpi.h"
 
 #ifdef __cplusplus
+/* *INDENT-OFF* */
 extern "C" {
+/* *INDENT-ON* */
 #endif
 
-#define HPIMSGX_ALLADAPTERS     (0xFFFF)
+#define HPIMSGX_ALLADAPTERS	(0xFFFF)
 
-	void HPIMSGX_MessageExAdapterReset(u16 wAdapterIndex);
+void HPI_MessageEx(
+	struct hpi_message *phm,
+	struct hpi_response *phr,
+	void *hOwner
+);
 
-	u16 HPIMSGX_MessageExAdapterInit(const HPI_HSUBSYS * phSubSysHandle, HPI_MESSAGE * phm,	// HPI_SUBSYS_CREATE_ADAPTER structure with
-// resource list or NULL=find all
-					 HPI_RESPONSE * phr	// response from HPI_ADAPTER_GET_INFO
-	    );
-
-	void HPIMSGX_MessageEx(const HPI_HSUBSYS * phSubSys,
-			       HPI_MESSAGE * phm,
-			       HPI_RESPONSE * phr, void *hOwner);
-
-	void HPIMSGX_MessageExAdapterCleanup(u16 wAdapterIndex, void *hOwner);
+#define HPI_MESSAGE_LOWER_LAYER HPI_MessageEx
 
 #ifdef __cplusplus
+/* *INDENT-OFF* */
 }
+/* *INDENT-ON* */
 #endif
+
 #endif				/* _HPIMSGX_H_ */
-///////////////////////////////////////////////////////////////////////////
